@@ -4,7 +4,7 @@ package Data::Record::Serialize::Role::Base;
 
 use Moo::Role;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use Data::Record::Serialize::Error { errors => [ 'fields' ] }, -all;
 
@@ -185,8 +185,6 @@ has _numify => (
 
 #pod =attr nullify
 #pod
-#pod   $obj->nullify( $array | $code | $bool );
-#pod
 #pod Specify which fields should be set to C<undef> if they are
 #pod empty. Sinks should encode C<undef> as the C<null> value.  By default,
 #pod no fields are nullified.
@@ -668,7 +666,7 @@ Data::Record::Serialize::Role::Base - Base Role for Data::Record::Serialize
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 DESCRIPTION
 
@@ -806,8 +804,6 @@ L</default_type>, please see L<Data::Record::Serialize/Fields and their types>.
 
 =head2 nullify
 
-  $obj->nullify( $array | $code | $bool );
-
 Specify which fields should be set to C<undef> if they are
 empty. Sinks should encode C<undef> as the C<null> value.  By default,
 no fields are nullified.
