@@ -4,11 +4,13 @@ package Data::Record::Serialize::Role::Default;
 
 use Moo::Role;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use Hash::Util qw[ hv_store ];
 use Ref::Util qw[ is_coderef ];
 
+use Data::Record::Serialize::Error { errors => [ 'fields' ] }, -all;
+
 use namespace::clean;
 
 #pod =for Pod::Coverage
@@ -51,6 +53,10 @@ around 'setup' => sub {
     $self->_set_fields( [ keys %$data ] )
       unless $self->has_fields;
 
+    # make sure there are no duplicate output fields
+    my %dups;
+    $dups{$_}++ && error( fields => "duplicate output field: $_" ) for@{$self->fields};
+
     if ( $self->_need_types ) {
 
         if ( $self->default_type ) {
@@ -154,7 +160,7 @@ Data::Record::Serialize::Role::Default - Default methods for Data::Record::Seria
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 DESCRIPTION
 
